==> threefive-2.0.61-py3-none-any.whl: threefive/splice.py <==
from base64 import b64decode
from bitn import BitBin
import json
import pprint
from threefive import (
    descriptors as dscprs,
    splice_info_section as spinfo,
    splice_commands as spcmd)


class Splice:
    '''
    The threefive.Splice class handles parsing
    SCTE 35 message strings.
    '''
    # map of known descriptors and associated classes
    descriptor_map = {0: dscprs.Avail_Descriptor,
                      1: dscprs.Dtmf_Descriptor,
                      2: dscprs.Segmentation_Descriptor,
                      3: dscprs.Time_Descriptor,
                      4: dscprs.Audio_Descriptor}
    
    # map of known splice commands and associated classes
    command_map = {0: spcmd.Splice_Null,
                   4: spcmd.Splice_Schedule,
                   5: spcmd.Splice_Insert,
                   6: spcmd.Time_Signal,
                   7: spcmd.Bandwidth_Reservation,
                   255: spcmd.Private_Command}

    def __init__(self, mesg,pid=False,pts=False):
        mesg = self.mkbits(mesg)
        if pid: self.pid = pid
        if pts: self.pts = pts
        self.infobb= BitBin(mesg[:14])
        self.bitbin=BitBin(mesg[14:])
        self.descriptors = []
        self.info_section = None
        self.command = None
        self.do()

    def do(self):
        self.info_section = spinfo.Splice_Info_Section()
        self.info_section.decode(self.infobb)
        self.set_splice_command()
        self.descriptorloop()
        self.info_section.crc = self.bitbin.ashex(32)

    def descriptorloop(self):
        self.info_section.descriptor_loop_length = self.bitbin.asint(16)
        dll = self.info_section.descriptor_loop_length
        tag_plus_header_size = 2  # 1 byte for descriptor_tag, 1 byte for header?
        while dll > 0:
            try:
                sd = self.set_splice_descriptor()
                sdl = sd.descriptor_length
                self.descriptors.append(sd)
            except:
                sdl = 0
            bit_move = sdl + tag_plus_header_size
            dll -= bit_move

    def kvprint(self, obj):
        print(vars(obj))

    def sectionstart(self, section_name):
        print(f'{section_name}')

    def mkbits(self, s):
        '''
        Convert Hex and Base64 strings into bytes.
        '''
        if s[:2].lower() == '0x': s = s[2:]
        if s[:2].lower() == 'fc': return bytes.fromhex(s)
        try: return b64decode(s)
        except: return s

    def set_splice_command(self):
        '''
        Splice Commands looked up in self.command_map
        '''
        sct = self.info_section.splice_command_type
        if sct not in self.command_map.keys():
            raise ValueError('Unknown Splice Command Type')
            return False
        self.command = self.command_map[sct]()
        self.command.decode(self.bitbin)

    def set_splice_descriptor(self):
        '''
        Splice Descriptors looked up in self.descriptor_map
        '''
        # splice_descriptor_tag 8 uimsbf
        tag = self.bitbin.asint(8)
        if tag in self.descriptor_map.keys():
            return self.descriptor_map[tag](self.bitbin, tag)
        else: return False

    def show_info_section(self):
        if self.info_section:
            return vars(self.info_section)
        else: return False

    def show_command(self):
        if self.command:
            return vars(self.info_section)
        else: return False

    def show_descriptors(self):
        dlist =[]
        if len(self.descriptors) > 0:
            for d in self.descriptors:
                dlist.append(vars(d))
        return dlist

    def show(self):
        jason ={}
        jason['Info_Section'] = self.show_info_section()
        jason['Splice_Command']= self.show_command()
        jason['Splice_Descriptors'] = self.show_descriptors()
        if self.pid or self.pts:
            packet = {}
            if self.pid: packet['pid'] = hex(self.pid)
            if self.pts: packet['pts'] = f'{self.pts:0.6f}'
            jason['Stream_Packet_Data'] = packet
            
        pprint.pprint(jason)

==> threefive-2.0.67-py3-none-any.whl: threefive/splice.py <==
from base64 import b64decode
from bitn import BitBin
import json
import pprint
from threefive import (
    descriptors as dscprs,
    splice_info_section as spinfo,
    splice_commands as spcmd)


class Splice:
    '''
    The threefive.Splice class handles parsing
    SCTE 35 message strings.
    '''
    # map of known descriptors and associated classes
    descriptor_map = {0: dscprs.Avail_Descriptor,
                      1: dscprs.Dtmf_Descriptor,
                      2: dscprs.Segmentation_Descriptor,
                      3: dscprs.Time_Descriptor,
                      4: dscprs.Audio_Descriptor}
    
    # map of known splice commands and associated classes
    command_map = {0: spcmd.Splice_Null,
                   4: spcmd.Splice_Schedule,
                   5: spcmd.Splice_Insert,
                   6: spcmd.Time_Signal,
                   7: spcmd.Bandwidth_Reservation,
                   255: spcmd.Private_Command}

    def __init__(self, mesg,pid=False,pts=False):
        mesg = self.mkbits(mesg)
        self.pid = pid
        self.pts = pts
        self.infobb= BitBin(mesg[:14])
        self.bitbin=BitBin(mesg[14:])
        self.descriptors = []
        self.info_section = None
        self.command = None
        self.do()

    def do(self):
        self.info_section = spinfo.Splice_Info_Section()
        self.info_section.decode(self.infobb)
        self.set_splice_command()
        self.descriptorloop()
        self.info_section.crc = self.bitbin.ashex(32)

    def descriptorloop(self):
        self.info_section.descriptor_loop_length = self.bitbin.asint(16)
        dll = self.info_section.descriptor_loop_length
        tag_plus_header_size = 2  # 1 byte for descriptor_tag, 1 byte for header?
        while dll > 0:
            try:
                sd = self.set_splice_descriptor()
                sdl = sd.descriptor_length
                self.descriptors.append(sd)
            except:
                sdl = 0
            bit_move = sdl + tag_plus_header_size
            dll -= bit_move

    def kvprint(self, obj):
        print(vars(obj))

    def mkbits(self, s):
        '''
        Convert Hex and Base64 strings into bytes.
        '''
        if s[:2].lower() == '0x': s = s[2:]
        if s[:2].lower() == 'fc': return bytes.fromhex(s)
        try: return b64decode(s)
        except: return s

    def set_splice_command(self):
        '''
        Splice Commands looked up in self.command_map
        '''
        sct = self.info_section.splice_command_type
        if sct not in self.command_map.keys():
            raise ValueError('Unknown Splice Command Type')
            return False
        self.command = self.command_map[sct]()
        self.command.decode(self.bitbin)

    def set_splice_descriptor(self):
        '''
        Splice Descriptors looked up in self.descriptor_map
        '''
        # splice_descriptor_tag 8 uimsbf
        tag = self.bitbin.asint(8)
        if tag in self.descriptor_map.keys():
            return self.descriptor_map[tag](self.bitbin, tag)
        else: return False

    def show_descriptors(self):
        dlist =[]
        if len(self.descriptors) > 0:
            for d in self.descriptors:
                dlist.append(vars(d))
        return dlist

    def show(self):
        scte35 = {'SCTE35' :{'Info_Section' : vars(self.info_section),
                               'Splice_Command': vars(self.command),
                                'Splice_Descriptors': self.show_descriptors()
                              }
                  }
        if self.pid or self.pts:
            packet = {}
            if self.pid: packet['pid'] = hex(self.pid)
            if self.pts: packet['pts'] = f'{self.pts:0.6f}'
            scte35['Packet'] = packet  
        pprint.pprint(scte35,width=40,indent=4)
